import { type Static } from '@sinclair/typebox';
import { DeviceShadow } from './DeviceShadow.js';
import type { FetchError } from './FetchError.js';
import { type ValidationError } from './validatedFetch.js';
declare const Devices: import("@sinclair/typebox").TObject<{
    total: import("@sinclair/typebox").TInteger;
    items: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        id: import("@sinclair/typebox").TString;
        $meta: import("@sinclair/typebox").TObject<{
            createdAt: import("@sinclair/typebox").TString;
            updatedAt: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
        }>;
        state: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TObject<{
            reported: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TAny>>;
            desired: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TAny>>;
            version: import("@sinclair/typebox").TNumber;
            metadata: import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TAny>;
        }>>;
    }>>;
}>;
/**
 * firmware types supported by a device for FOTA
 */
export declare enum FwType {
    APP = "APP",
    MODEM = "MODEM",
    BOOT = "BOOT",
    SOFTDEVICE = "SOFTDEVICE",
    BOOTLOADER = "BOOTLOADER",
    MDM_FULL = "MDM_FULL"
}
export declare const devices: ({ endpoint, apiKey, }: {
    endpoint: URL;
    apiKey: string;
}, fetchImplementation?: typeof fetch) => {
    list: () => Promise<{
        error: FetchError | ValidationError;
    } | {
        result: Static<typeof Devices>;
    }>;
    get: (id: string) => Promise<{
        error: FetchError | ValidationError;
    } | {
        result: Static<typeof DeviceShadow>;
    }>;
    updateState: (id: string, state: {
        desired?: Record<string, any>;
        reported?: Record<string, any>;
    }) => Promise<{
        error: FetchError | ValidationError;
    } | {
        success: boolean;
    }>;
    register: (devices: {
        deviceId: string;
        certPem: string;
        subType?: string;
        tags?: string[];
        /**
         * A list of pipe-delimited firmware types that each device supports for FOTA (e.g., APP|MODEM)
         *
         * Defaults to all supported (APP|MODEM|BOOT|SOFTDEVICE|BOOTLOADER|MDM_FULL)
         *
         * @default 'APP|MODEM|BOOT|SOFTDEVICE|BOOTLOADER|MDM_FULL'
         */
        fwTypes?: FwType[];
    }[]) => Promise<{
        error: FetchError | ValidationError;
    } | {
        bulkOpsRequestId: string;
    }>;
    remove: (deviceId: string) => Promise<{
        error: FetchError | ValidationError;
    } | {
        success: boolean;
    }>;
};
export {};
